@@ -28,6 +28,13 @@ class TomeLoader:
         """If the tome exists"""
         return self._reader.exists
 
+    @property
+    def is_complete(self):
+        """If the tome is complete"""
+        if not self._reader.exists:
+            return False
+        return self.manifest.get("isComplete", False)
+
     @property
     def manifest(self):
         """Tome manifest"""
